@@ -9,26 +9,6 @@ our $VERSION = '1.00';
 
 our @EXPORT_OK;
 
-# @todo This must be implemented with XS part (already written)
-push @EXPORT_OK, 'html_protect';
-our %HTML_PROTECT = (
-    '<' => '&lt;',
-    '>' => '&gt;',
-    '\'' => '&#39;',
-    '"' => '&quot;',
-    '&' => '&amp;',
-);
-
-our $HTML_PROTECT_RE = join '|', keys %HTML_PROTECT;
-
-sub html_protect
-{
-    my $text = shift;
-    return $text if not defined $text;
-    $text =~ s/($HTML_PROTECT_RE)/$HTML_PROTECT{$1}/g;
-    return $text;
-}
-
 # @todo what with timezones?
 push @EXPORT_OK, 'time2str';
 sub time2str
@@ -260,22 +240,16 @@ sub time2str_php
 ### end of Dotiac::DTL code
 
 push @EXPORT_OK, 'uri_escape';
-sub uri_escape{return URI::Escape::XS::uri_escape(shift);}
+*DTL::Fast::Utils::uri_escape = \&URI::Escape::XS::uri_escape;
 
 push @EXPORT_OK, 'uri_unescape';
-sub uri_unescape{return URI::Escape::XS::uri_unescape(shift);}
+*DTL::Fast::Utils::uri_unescape = \&URI::Escape::XS::uri_unescape;
 
 push @EXPORT_OK, 'escape';
-sub escape{return URI::Escape::XS::encodeURIComponent(shift);}
+*DTL::Fast::Utils::escape = \&URI::Escape::XS::encodeURIComponent;
 
 push @EXPORT_OK, 'unescape';
-sub unescape{return URI::Escape::XS::decodeURIComponent(shift);}
-
-our %BOOL_PROCESSORS = (
-    'SCALAR' => sub{ my $value = shift; return $$value; }
-    , 'HASH' => sub{ my $value = shift; return scalar keys(%$value); }
-    , 'ARRAY' => sub{ my $value = shift; return scalar @$value; }
-);
+*DTL::Fast::Utils::unescape = \&URI::Escape::XS::decodeURIComponent;
 
 push @EXPORT_OK, 'as_bool';
 sub as_bool
@@ -285,9 +259,17 @@ sub as_bool
 
     if( $value_type )
     {
-        if( $BOOL_PROCESSORS{$value_type} )
+        if ( $value_type eq 'SCALAR' )
         {
-            $value = $BOOL_PROCESSORS{$value_type}->($value);
+            $value = $$value;
+        }
+        elsif( $value_type eq 'HASH' )
+        {
+            $value = scalar keys(%$value);
+        }
+        elsif( $value_type eq 'ARRAY' )
+        {
+            $value = scalar @$value;
         }
         elsif( UNIVERSAL::can( $value, 'as_bool' ) )
         {
