@@ -96,4 +96,6 @@ runtests(
     't/tag/widthratio.t',
     't/tag/with.t',
     't/xs/spaceless.t',
+    't/xs/eval_sequence.t',
+    't/xs/html_protect.t',
 );
\ No newline at end of file
